@@ -18,7 +18,7 @@
 #ifndef DIFFMODELLIST_H
 #define DIFFMODELLIST_H
 
-#include <QtCore/QList> // include for the base class
+#include <QList> // include for the base class
 
 #include "diffmodel.h"
 #include "diff2_export.h"
@@ -32,17 +32,15 @@ typedef QList<DiffModel*>::ConstIterator DiffModelListConstIterator;
 class DIFF2_EXPORT DiffModelList : public QList<DiffModel*>
 {
 public:
-	DiffModelList() {}
-	DiffModelList( const DiffModelList &list ) : QList<DiffModel*>( list ) {}
-	virtual ~DiffModelList()
-	{
-		// Memleak as indicated by valgrind
-		while ( !isEmpty() )
-			delete takeFirst();
-	}
+    DiffModelList() {}
+    DiffModelList(const DiffModelList& list) : QList<DiffModel*>(list) {}
+    virtual ~DiffModelList()
+    {
+        qDeleteAll(begin(), end());
+    }
 
 public:
-	virtual void sort();
+    virtual void sort();
 
 }; // End of class DiffModelList
 
